#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 half
version:              0.3.3
visibility:           public
id:                   half-0.3.3-7Pe1x9OfmqnD6mFPUnyuYB
key:                  half-0.3.3-7Pe1x9OfmqnD6mFPUnyuYB
license:              BSD-3-Clause
copyright:            Copyright (C) 2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/half
synopsis:             Half-precision floating-point
description:          Half-precision floating-point.
category:             Numeric
abi:                  897354c3fa9a6545bf2c3da2c579179a
exposed:              True
exposed-modules:      Numeric.Half Numeric.Half.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/half-0.3.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/half-0.3.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/half-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-half
hs-libraries:         HShalf-0.3.3-7Pe1x9OfmqnD6mFPUnyuYB
depends:
    base-4.18.2.1 binary-0.8.9.1 deepseq-1.4.8.1
    template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-half/html/half.haddock
haddock-html:         /usr/share/doc/haskell-half/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

